Class: VitableConnect::Models::Employee
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- VitableConnect::Models::Employee
- Defined in:
- lib/vitable_connect/models/employee.rb
Defined Under Namespace
Classes: Address, Deduction, Enrollment
Instance Attribute Summary collapse
-
#address ⇒ VitableConnect::Models::Employee::Address?
Employee’s residential address.
-
#created_at ⇒ Time
Timestamp when the employee was created.
-
#date_of_birth ⇒ Date
Date of birth (YYYY-MM-DD).
-
#deductions ⇒ Array<VitableConnect::Models::Employee::Deduction>
Payroll deductions from the most recent statement period.
-
#email ⇒ String
Email address.
-
#employee_class ⇒ Symbol, ...
-
‘Full Time` - Full Time - `Part Time` - Part Time - `Temporary` - Temporary - `Intern` - Intern - `Seasonal` - Seasonal - `Individual Contractor` - Individual Contractor.
-
-
#enrollments ⇒ Array<VitableConnect::Models::Employee::Enrollment>
Benefit enrollments for this employee.
-
#first_name ⇒ String
Employee’s legal first name.
-
#gender ⇒ String?
Gender identity, if provided.
-
#hire_date ⇒ Date?
Employee’s hire date with the employer.
-
#last_name ⇒ String
Employee’s legal last name.
-
#phone ⇒ String?
Phone number (10-digit US domestic string).
-
#reference_id ⇒ String?
Partner-assigned reference ID for the employee.
-
#suffix ⇒ String?
Name suffix (e.g., Jr., Sr., III).
-
#termination_date ⇒ Date?
Employee’s termination date, if terminated.
-
#updated_at ⇒ Time
Timestamp when the employee was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, status:, answered_at: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Enrollment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, status:, answered_at: nil) ⇒ Object
Some parameter documentations has been truncated, see Enrollment for more details.
|
|
# File 'lib/vitable_connect/models/employee.rb', line 296
|
Instance Attribute Details
#address ⇒ VitableConnect::Models::Employee::Address?
Employee’s residential address
60 |
# File 'lib/vitable_connect/models/employee.rb', line 60 optional :address, -> { VitableConnect::Employee::Address }, nil?: true |
#created_at ⇒ Time
Timestamp when the employee was created
10 |
# File 'lib/vitable_connect/models/employee.rb', line 10 required :created_at, Time |
#date_of_birth ⇒ Date
Date of birth (YYYY-MM-DD)
16 |
# File 'lib/vitable_connect/models/employee.rb', line 16 required :date_of_birth, Date |
#deductions ⇒ Array<VitableConnect::Models::Employee::Deduction>
Payroll deductions from the most recent statement period. Replaced when a new statement is generated.
23 |
# File 'lib/vitable_connect/models/employee.rb', line 23 required :deductions, -> { VitableConnect::Internal::Type::ArrayOf[VitableConnect::Employee::Deduction] } |
#email ⇒ String
Email address
29 |
# File 'lib/vitable_connect/models/employee.rb', line 29 required :email, String |
#employee_class ⇒ Symbol, ...
-
‘Full Time` - Full Time
-
‘Part Time` - Part Time
-
‘Temporary` - Temporary
-
‘Intern` - Intern
-
‘Seasonal` - Seasonal
-
‘Individual Contractor` - Individual Contractor
71 |
# File 'lib/vitable_connect/models/employee.rb', line 71 optional :employee_class, enum: -> { VitableConnect::EmployeeClass }, nil?: true |
#enrollments ⇒ Array<VitableConnect::Models::Employee::Enrollment>
Benefit enrollments for this employee
35 36 |
# File 'lib/vitable_connect/models/employee.rb', line 35 required :enrollments, -> { VitableConnect::Internal::Type::ArrayOf[VitableConnect::Employee::Enrollment] } |
#first_name ⇒ String
Employee’s legal first name
42 |
# File 'lib/vitable_connect/models/employee.rb', line 42 required :first_name, String |
#gender ⇒ String?
Gender identity, if provided
77 |
# File 'lib/vitable_connect/models/employee.rb', line 77 optional :gender, String, nil?: true |
#hire_date ⇒ Date?
Employee’s hire date with the employer
83 |
# File 'lib/vitable_connect/models/employee.rb', line 83 optional :hire_date, Date, nil?: true |
#last_name ⇒ String
Employee’s legal last name
48 |
# File 'lib/vitable_connect/models/employee.rb', line 48 required :last_name, String |
#phone ⇒ String?
Phone number (10-digit US domestic string)
89 |
# File 'lib/vitable_connect/models/employee.rb', line 89 optional :phone, String, nil?: true |
#reference_id ⇒ String?
Partner-assigned reference ID for the employee
95 |
# File 'lib/vitable_connect/models/employee.rb', line 95 optional :reference_id, String, nil?: true |
#suffix ⇒ String?
Name suffix (e.g., Jr., Sr., III)
101 |
# File 'lib/vitable_connect/models/employee.rb', line 101 optional :suffix, String, nil?: true |
#termination_date ⇒ Date?
Employee’s termination date, if terminated
107 |
# File 'lib/vitable_connect/models/employee.rb', line 107 optional :termination_date, Date, nil?: true |
#updated_at ⇒ Time
Timestamp when the employee was last updated
54 |
# File 'lib/vitable_connect/models/employee.rb', line 54 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/vitable_connect/models/employee.rb', line 267
|