Class: VitableConnect::Models::EmployeeUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- VitableConnect::Models::EmployeeUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/vitable_connect/models/employee_update_params.rb,
sig/vitable_connect/models/employee_update_params.rbs
Overview
Defined Under Namespace
Modules: CompensationType, Gender Classes: Address
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::VitableConnect
Instance Attribute Summary collapse
-
#address ⇒ VitableConnect::Models::EmployeeUpdateParams::Address?
Employee's residential address.
-
#compensation_type ⇒ Symbol, ...
Salary- Salary -Hourly- Hourly.
-
#effective_date ⇒ Date
Past or present date applied to each tracked employment field included in this request.
-
#email ⇒ String?
Email address.
-
#employee_class ⇒ Symbol, ...
Full Time- Full Time -Part Time- Part Time -Temporary- Temporary -Intern- Intern -Seasonal- Seasonal -Individual Contractor- Individual Contractor.
-
#employee_id ⇒ String
Unique employee identifier (empl_*).
-
#gender ⇒ Symbol, ...
Male- Male -Female- Female -Transgender- Transgender -Non-binary- Non-binary -Prefer not to respond- Prefer not to respond.
-
#phone ⇒ String?
Phone number.
-
#start_date ⇒ Date?
Employment start date.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, state:, street_1:, zip_code:, country: nil, street_2: nil) ⇒ Object
constructor
Employee's residential address.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, state:, street_1:, zip_code:, country: nil, street_2: nil) ⇒ Object
Employee's residential address
|
|
# File 'lib/vitable_connect/models/employee_update_params.rb', line 138
|
Instance Attribute Details
#address ⇒ VitableConnect::Models::EmployeeUpdateParams::Address?
Employee's residential address
27 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 27 optional :address, -> { VitableConnect::EmployeeUpdateParams::Address }, nil?: true |
#compensation_type ⇒ Symbol, ...
Salary- SalaryHourly- Hourly
34 35 36 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 34 optional :compensation_type, enum: -> { VitableConnect::EmployeeUpdateParams::CompensationType }, nil?: true |
#effective_date ⇒ Date
Past or present date applied to each tracked employment field included in this request
21 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 21 required :effective_date, Date |
#email ⇒ String?
Email address
42 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 42 optional :email, String, nil?: true |
#employee_class ⇒ Symbol, ...
Full Time- Full TimePart Time- Part TimeTemporary- TemporaryIntern- InternSeasonal- SeasonalIndividual Contractor- Individual Contractor
53 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 53 optional :employee_class, enum: -> { VitableConnect::EmployeeClass }, nil?: true |
#employee_id ⇒ String
Unique employee identifier (empl_*)
14 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 14 required :employee_id, String |
#gender ⇒ Symbol, ...
Male- MaleFemale- FemaleTransgender- TransgenderNon-binary- Non-binaryPrefer not to respond- Prefer not to respond
63 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 63 optional :gender, enum: -> { VitableConnect::EmployeeUpdateParams::Gender }, nil?: true |
#phone ⇒ String?
Phone number
69 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 69 optional :phone, String, nil?: true |
#start_date ⇒ Date?
Employment start date
75 |
# File 'lib/vitable_connect/models/employee_update_params.rb', line 75 optional :start_date, Date, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/vitable_connect/models/employee_update_params.rb', line 162
|
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/vitable_connect/models/employee_update_params.rbs', line 52
def to_hash: -> {
|