Class: VitableConnect::Models::Employer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- VitableConnect::Models::Employer
- Defined in:
- lib/vitable_connect/models/employer.rb,
sig/vitable_connect/models/employer.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#active ⇒ Boolean
Whether the employer is currently active in the system.
-
#address ⇒ VitableConnect::Models::Employer::Address
Nested address within EmployerSerializer.
-
#contact ⇒ VitableConnect::Employer::Contact?
Returns the value of attribute contact.
-
#created_at ⇒ Time
Timestamp when the employer was created.
-
#ein ⇒ String?
Returns the value of attribute ein.
-
#email ⇒ String?
Email address for billing and communications.
-
#id ⇒ String
Returns the value of attribute id.
-
#legal_name ⇒ String
Legal business name for compliance and tax purposes.
-
#name ⇒ String
Display name of the employer.
-
#organization_id ⇒ String?
Returns the value of attribute organization_id.
-
#phone_number ⇒ String?
Employer phone number (E.164 format recommended).
-
#reference_id ⇒ String?
Partner-assigned reference ID for the employer.
-
#updated_at ⇒ Time
Timestamp when the employer was last updated.
Instance Method Summary collapse
-
#initialize(address_line_1:, city:, state:, zipcode:, address_line_2: nil) ⇒ Object
constructor
Nested address within EmployerSerializer.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(address_line_1:, city:, state:, zipcode:, address_line_2: nil) ⇒ Object
Nested address within EmployerSerializer.
|
|
# File 'lib/vitable_connect/models/employer.rb', line 87
|
Instance Attribute Details
#active ⇒ Boolean
Whether the employer is currently active in the system
10 |
# File 'lib/vitable_connect/models/employer.rb', line 10 required :active, VitableConnect::Internal::Type::Boolean |
#address ⇒ VitableConnect::Models::Employer::Address
Nested address within EmployerSerializer.
16 |
# File 'lib/vitable_connect/models/employer.rb', line 16 required :address, -> { VitableConnect::Employer::Address } |
#contact ⇒ VitableConnect::Employer::Contact?
Returns the value of attribute contact.
41 42 43 |
# File 'sig/vitable_connect/models/employer.rbs', line 41 def contact @contact end |
#created_at ⇒ Time
Timestamp when the employer was created
22 |
# File 'lib/vitable_connect/models/employer.rb', line 22 required :created_at, Time |
#ein ⇒ String?
Returns the value of attribute ein.
43 44 45 |
# File 'sig/vitable_connect/models/employer.rbs', line 43 def ein @ein end |
#email ⇒ String?
Email address for billing and communications
46 |
# File 'lib/vitable_connect/models/employer.rb', line 46 optional :email, String, nil?: true |
#id ⇒ String
Returns the value of attribute id.
39 40 41 |
# File 'sig/vitable_connect/models/employer.rbs', line 39 def id @id end |
#legal_name ⇒ String
Legal business name for compliance and tax purposes
28 |
# File 'lib/vitable_connect/models/employer.rb', line 28 required :legal_name, String |
#name ⇒ String
Display name of the employer
34 |
# File 'lib/vitable_connect/models/employer.rb', line 34 required :name, String |
#organization_id ⇒ String?
Returns the value of attribute organization_id.
45 46 47 |
# File 'sig/vitable_connect/models/employer.rbs', line 45 def organization_id @organization_id end |
#phone_number ⇒ String?
Employer phone number (E.164 format recommended)
52 |
# File 'lib/vitable_connect/models/employer.rb', line 52 optional :phone_number, String, nil?: true |
#reference_id ⇒ String?
Partner-assigned reference ID for the employer
58 |
# File 'lib/vitable_connect/models/employer.rb', line 58 optional :reference_id, String, nil?: true |
#updated_at ⇒ Time
Timestamp when the employer was last updated
40 |
# File 'lib/vitable_connect/models/employer.rb', line 40 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
63 |
# File 'sig/vitable_connect/models/employer.rbs', line 63
def to_hash: -> {
|