Class: VitableConnect::Models::EmployerListHRISProvidersResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/vitable_connect/models/employer_list_hris_providers_response.rb,
sig/vitable_connect/models/employer_list_hris_providers_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(provider:) ⇒ Data

Returns a new instance of Data.

Parameters:

  • provider (String)

    HRIS/payroll provider name, as stored on the connection (e.g. ADP RUN).

  • provider: (String)


18
19
20
21
22
23
24
25
26
27
# File 'lib/vitable_connect/models/employer_list_hris_providers_response.rb', line 18

class Data < VitableConnect::Internal::Type::BaseModel
  # @!attribute provider
  #   HRIS/payroll provider name, as stored on the connection (e.g. `ADP RUN`).
  #
  #   @return [String]
  required :provider, String

  # @!method initialize(provider:)
  #   @param provider [String] HRIS/payroll provider name, as stored on the connection (e.g. `ADP RUN`).
end

Instance Attribute Details

#providerString

HRIS/payroll provider name, as stored on the connection (e.g. ADP RUN).

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/vitable_connect/models/employer_list_hris_providers_response.rb', line 23

required :provider, String

Instance Method Details

#to_hash{ provider: String }

Returns:

  • ({ provider: String })


26
# File 'sig/vitable_connect/models/employer_list_hris_providers_response.rbs', line 26

def to_hash: -> { provider: String }