Class: VitableConnect::Models::EmployerRetrieveHRISResponse::HRIS

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/vitable_connect/models/employer_retrieve_hris_response.rb,
sig/vitable_connect/models/employer_retrieve_hris_response.rbs

Overview

See Also:

  • VitableConnect::Models::EmployerRetrieveHRISResponse#hris

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(last_sync_on:, provider:, status:, synced_row_count:) ⇒ Object

HRIS connection details, or null when the employer has no integration.

Parameters:

  • last_sync_on (Time, nil)

    When the last sync completed, or null when none has.

  • provider (String)

    HRIS/payroll provider the employer is connected to (e.g. Paychex).

  • status (String)

    Connection status reported by the integration.

  • synced_row_count (Integer, nil)

    Rows in the latest completed sync, or null when none has.



# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 42

Instance Attribute Details

#last_sync_onTime?

When the last sync completed, or null when none has.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


22
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 22

required :last_sync_on, Time, nil?: true

#providerString

HRIS/payroll provider the employer is connected to (e.g. Paychex).

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 28

required :provider, String

#statusString

Connection status reported by the integration.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 34

required :status, String

#synced_row_countInteger?

Rows in the latest completed sync, or null when none has.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


40
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 40

required :synced_row_count, Integer, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


41
# File 'sig/vitable_connect/models/employer_retrieve_hris_response.rbs', line 41

def to_hash: -> {