Class: VitableConnect::Models::WebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/vitable_connect/models/webhook_event.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, event_name:, organization_id:, resource_id:, resource_type:) ⇒ Object

Some parameter documentations has been truncated, see VitableConnect::Models::WebhookEvent for more details.

Parameters:

  • id (String)

    Prefixed unique identifier for this webhook event (e.g., ‘wevt_…`).

  • created_at (Time)

    When the event occurred, in UTC.

  • event_name (String)

    The event type, formatted as ‘resource.action` (e.g., `enrollment.accepted`)

  • organization_id (String)

    The organization this event belongs to.

  • resource_id (String)

    Prefixed ID of the affected resource. Use this to fetch the current state from t

  • resource_type (String)

    The type of resource affected (e.g., ‘enrollment`, `employee`).



# File 'lib/vitable_connect/models/webhook_event.rb', line 45

Instance Attribute Details

#created_atTime

When the event occurred, in UTC.

Returns:

  • (Time)


17
# File 'lib/vitable_connect/models/webhook_event.rb', line 17

required :created_at, Time

#event_nameString

The event type, formatted as ‘resource.action` (e.g., `enrollment.accepted`).

Returns:

  • (String)


24
# File 'lib/vitable_connect/models/webhook_event.rb', line 24

required :event_name, String

#idString

Prefixed unique identifier for this webhook event (e.g., ‘wevt_…`).

Returns:

  • (String)


11
# File 'lib/vitable_connect/models/webhook_event.rb', line 11

required :id, String

#organization_idString

The organization this event belongs to.

Returns:

  • (String)


30
# File 'lib/vitable_connect/models/webhook_event.rb', line 30

required :organization_id, String

#resource_idString

Prefixed ID of the affected resource. Use this to fetch the current state from the API.

Returns:

  • (String)


37
# File 'lib/vitable_connect/models/webhook_event.rb', line 37

required :resource_id, String

#resource_typeString

The type of resource affected (e.g., ‘enrollment`, `employee`).

Returns:

  • (String)


43
# File 'lib/vitable_connect/models/webhook_event.rb', line 43

required :resource_type, String