Class: VitableConnect::Models::WebhookEventListDeliveriesResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/vitable_connect/models/webhook_event_list_deliveries_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, delivered_at:, failed_at:, failure_reason:, started_at:, status:, subscription_id:, webhook_event_id:) ⇒ Object

Parameters:

  • id (String)

    Prefixed unique identifier for this delivery (e.g., ‘wdlv_…`).

  • created_at (Time)

    When this delivery record was created, in UTC.

  • delivered_at (Time, nil)

    When the delivery was successfully received, in UTC.

  • failed_at (Time, nil)

    When the delivery was marked as permanently failed, in UTC.

  • failure_reason (String)

    Reason for failure, if applicable.

  • started_at (Time, nil)

    When the delivery attempt started, in UTC.

  • status (String)

    Current delivery status: Pending, In Progress, Delivered, or Failed.

  • subscription_id (String)

    The webhook subscription this delivery was sent to.

  • webhook_event_id (String)

    The webhook event this delivery belongs to.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 16

class Data < VitableConnect::Internal::Type::BaseModel
  # @!attribute id
  #   Prefixed unique identifier for this delivery (e.g., `wdlv_...`).
  #
  #   @return [String]
  required :id, String

  # @!attribute created_at
  #   When this delivery record was created, in UTC.
  #
  #   @return [Time]
  required :created_at, Time

  # @!attribute delivered_at
  #   When the delivery was successfully received, in UTC.
  #
  #   @return [Time, nil]
  required :delivered_at, Time, nil?: true

  # @!attribute failed_at
  #   When the delivery was marked as permanently failed, in UTC.
  #
  #   @return [Time, nil]
  required :failed_at, Time, nil?: true

  # @!attribute failure_reason
  #   Reason for failure, if applicable.
  #
  #   @return [String]
  required :failure_reason, String

  # @!attribute started_at
  #   When the delivery attempt started, in UTC.
  #
  #   @return [Time, nil]
  required :started_at, Time, nil?: true

  # @!attribute status
  #   Current delivery status: Pending, In Progress, Delivered, or Failed.
  #
  #   @return [String]
  required :status, String

  # @!attribute subscription_id
  #   The webhook subscription this delivery was sent to.
  #
  #   @return [String]
  required :subscription_id, String

  # @!attribute webhook_event_id
  #   The webhook event this delivery belongs to.
  #
  #   @return [String]
  required :webhook_event_id, String

  # @!method initialize(id:, created_at:, delivered_at:, failed_at:, failure_reason:, started_at:, status:, subscription_id:, webhook_event_id:)
  #   @param id [String] Prefixed unique identifier for this delivery (e.g., `wdlv_...`).
  #
  #   @param created_at [Time] When this delivery record was created, in UTC.
  #
  #   @param delivered_at [Time, nil] When the delivery was successfully received, in UTC.
  #
  #   @param failed_at [Time, nil] When the delivery was marked as permanently failed, in UTC.
  #
  #   @param failure_reason [String] Reason for failure, if applicable.
  #
  #   @param started_at [Time, nil] When the delivery attempt started, in UTC.
  #
  #   @param status [String] Current delivery status: Pending, In Progress, Delivered, or Failed.
  #
  #   @param subscription_id [String] The webhook subscription this delivery was sent to.
  #
  #   @param webhook_event_id [String] The webhook event this delivery belongs to.
end

Instance Attribute Details

#created_atTime

When this delivery record was created, in UTC.

Returns:

  • (Time)


27
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 27

required :created_at, Time

#delivered_atTime?

When the delivery was successfully received, in UTC.

Returns:

  • (Time, nil)


33
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 33

required :delivered_at, Time, nil?: true

#failed_atTime?

When the delivery was marked as permanently failed, in UTC.

Returns:

  • (Time, nil)


39
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 39

required :failed_at, Time, nil?: true

#failure_reasonString

Reason for failure, if applicable.

Returns:

  • (String)


45
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 45

required :failure_reason, String

#idString

Prefixed unique identifier for this delivery (e.g., ‘wdlv_…`).

Returns:

  • (String)


21
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 21

required :id, String

#started_atTime?

When the delivery attempt started, in UTC.

Returns:

  • (Time, nil)


51
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 51

required :started_at, Time, nil?: true

#statusString

Current delivery status: Pending, In Progress, Delivered, or Failed.

Returns:

  • (String)


57
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 57

required :status, String

#subscription_idString

The webhook subscription this delivery was sent to.

Returns:

  • (String)


63
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 63

required :subscription_id, String

#webhook_event_idString

The webhook event this delivery belongs to.

Returns:

  • (String)


69
# File 'lib/vitable_connect/models/webhook_event_list_deliveries_response.rb', line 69

required :webhook_event_id, String