Class: VitableConnect::Resources::Plans
- Inherits:
-
Object
- Object
- VitableConnect::Resources::Plans
- Defined in:
- lib/vitable_connect/resources/plans.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Plans
constructor
private
A new instance of Plans.
-
#list(limit: nil, page: nil, request_options: {}) ⇒ VitableConnect::Internal::PageNumberPage<VitableConnect::Models::PlanListResponse>
Returns a paginated list of benefit plans linked to the authenticated organization.
Constructor Details
#initialize(client:) ⇒ Plans
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Plans.
36 37 38 |
# File 'lib/vitable_connect/resources/plans.rb', line 36 def initialize(client:) @client = client end |
Instance Method Details
#list(limit: nil, page: nil, request_options: {}) ⇒ VitableConnect::Internal::PageNumberPage<VitableConnect::Models::PlanListResponse>
Returns a paginated list of benefit plans linked to the authenticated organization.
20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'lib/vitable_connect/resources/plans.rb', line 20 def list(params = {}) parsed, = VitableConnect::PlanListParams.dump_request(params) query = VitableConnect::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "v1/plans", query: query, page: VitableConnect::Internal::PageNumberPage, model: VitableConnect::Models::PlanListResponse, options: ) end |