Class: VitableConnect::Types::EnrollmentDetail
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- VitableConnect::Types::EnrollmentDetail
- Defined in:
- lib/VitableConnect/types/enrollment_detail.rb
Overview
A single enrollment, including the enrolled plan's documents.
The plan documents are resolved one enrollment at a time and are therefore not part of the list row.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from VitableConnect::Internal::Types::Model