Class: VitableConnect::Models::EmployerRetrieveHRISResponse::HRIS
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- VitableConnect::Models::EmployerRetrieveHRISResponse::HRIS
- Defined in:
- lib/vitable_connect/models/employer_retrieve_hris_response.rb,
sig/vitable_connect/models/employer_retrieve_hris_response.rbs
Overview
Instance Attribute Summary collapse
-
#last_sync_on ⇒ Time?
When the last sync completed, or null when none has.
-
#provider ⇒ String
HRIS/payroll provider the employer is connected to (e.g.
Paychex). -
#status ⇒ String
Connection status reported by the integration.
-
#synced_row_count ⇒ Integer?
Rows in the latest completed sync, or null when none has.
Instance Method Summary collapse
-
#initialize(last_sync_on:, provider:, status:, synced_row_count:) ⇒ Object
constructor
HRIS connection details, or null when the employer has no integration.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(last_sync_on:, provider:, status:, synced_row_count:) ⇒ Object
HRIS connection details, or null when the employer has no integration.
|
|
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 42
|
Instance Attribute Details
#last_sync_on ⇒ Time?
When the last sync completed, or null when none has.
22 |
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 22 required :last_sync_on, Time, nil?: true |
#provider ⇒ String
HRIS/payroll provider the employer is connected to (e.g. Paychex).
28 |
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 28 required :provider, String |
#status ⇒ String
Connection status reported by the integration.
34 |
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 34 required :status, String |
#synced_row_count ⇒ Integer?
Rows in the latest completed sync, or null when none has.
40 |
# File 'lib/vitable_connect/models/employer_retrieve_hris_response.rb', line 40 required :synced_row_count, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/vitable_connect/models/employer_retrieve_hris_response.rbs', line 41
def to_hash: -> {
|