Class: VitableConnect::Organizations::Client
- Inherits:
-
Object
- Object
- VitableConnect::Organizations::Client
- Defined in:
- lib/VitableConnect/organizations/client.rb
Instance Method Summary collapse
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **_params) ⇒ VitableConnect::Types::OrganizationsListResponse
Lists the organizations the authenticated caller is an active member of (paginated), each with the role the caller holds in it.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/VitableConnect/organizations/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}, **_params) ⇒ VitableConnect::Types::OrganizationsListResponse
Lists the organizations the authenticated caller is an active member of (paginated), each with the role the caller holds in it. Returns an empty list when the caller belongs to no organizations.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/VitableConnect/organizations/client.rb', line 28 def list(request_options: {}, **_params) request = VitableConnect::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "v1/organizations", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise VitableConnect::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) VitableConnect::Types::OrganizationsListResponse.load(response.body) else error_class = VitableConnect::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |