Class: VitableConnect::Resources::Enrollments
- Inherits:
-
Object
- Object
- VitableConnect::Resources::Enrollments
- Defined in:
- lib/vitable_connect/resources/enrollments.rb
Overview
Manage benefit enrollments and elections for employees
Instance Method Summary collapse
-
#initialize(client:) ⇒ Enrollments
constructor
private
A new instance of Enrollments.
-
#retrieve(enrollment_id, request_options: {}) ⇒ VitableConnect::Models::EnrollmentRetrieveResponse
Retrieves detailed information for a specific enrollment by ID.
Constructor Details
#initialize(client:) ⇒ Enrollments
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Enrollments.
30 31 32 |
# File 'lib/vitable_connect/resources/enrollments.rb', line 30 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(enrollment_id, request_options: {}) ⇒ VitableConnect::Models::EnrollmentRetrieveResponse
Retrieves detailed information for a specific enrollment by ID.
18 19 20 21 22 23 24 25 |
# File 'lib/vitable_connect/resources/enrollments.rb', line 18 def retrieve(enrollment_id, params = {}) @client.request( method: :get, path: ["v1/enrollments/%1$s", enrollment_id], model: VitableConnect::Models::EnrollmentRetrieveResponse, options: params[:request_options] ) end |